==> jc-1.4.0.tar.gz: javax/swing/event/TreeExpansionEvent.h <==
// public class javax.swing.event.TreeExpansionEvent

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 60b136e49bd0d068 javax_swing_event_TreeExpansionEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_swing_event_TreeExpansionEvent_H_
#define _JC_javax_swing_event_TreeExpansionEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_swing_tree_TreePath$object;

// Typedefs
typedef struct _jc_javax_swing_event_TreeExpansionEvent$sub_refs	_jc_javax_swing_event_TreeExpansionEvent$sub_refs;
typedef struct _jc_javax_swing_event_TreeExpansionEvent$sub_nonrefs	_jc_javax_swing_event_TreeExpansionEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_TreeExpansionEvent$refs	_jc_javax_swing_event_TreeExpansionEvent$refs;
typedef struct _jc_javax_swing_event_TreeExpansionEvent$nonrefs	_jc_javax_swing_event_TreeExpansionEvent$nonrefs;
typedef struct _jc_javax_swing_event_TreeExpansionEvent$object	_jc_javax_swing_event_TreeExpansionEvent$object;

typedef const struct _jc_javax_swing_event_TreeExpansionEvent$vmethods	_jc_javax_swing_event_TreeExpansionEvent$vmethods;
typedef const struct _jc_javax_swing_event_TreeExpansionEvent$vtable	_jc_javax_swing_event_TreeExpansionEvent$vtable;
typedef const struct _jc_javax_swing_event_TreeExpansionEvent$vtype	_jc_javax_swing_event_TreeExpansionEvent$vtype;

// Constructors
extern void _jc_javax_swing_event_TreeExpansionEvent$method$_init$a701a601c3e52853(_jc_env *, struct _jc_javax_swing_event_TreeExpansionEvent$object *, struct _jc_java_lang_Object$object *, struct _jc_javax_swing_tree_TreePath$object *);

// Virtual methods
extern struct _jc_javax_swing_tree_TreePath$object *_jc_javax_swing_event_TreeExpansionEvent$method$getPath$e6c9a7eed2216189(_jc_env *, struct _jc_javax_swing_event_TreeExpansionEvent$object *);
extern void _jc_javax_swing_event_TreeExpansionEvent$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_event_TreeExpansionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_TreeExpansionEvent$method_info$getPath$e6c9a7eed2216189;
extern _jc_method _jc_javax_swing_event_TreeExpansionEvent$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_event_TreeExpansionEvent$vmethods {
	struct _jc_javax_swing_tree_TreePath$object	*(*getPath$e6c9a7eed2216189)(_jc_env *, struct _jc_javax_swing_event_TreeExpansionEvent$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_event_TreeExpansionEvent$object *);
};

// Vtable
struct _jc_javax_swing_event_TreeExpansionEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_swing_event_TreeExpansionEvent$vmethods	javax_swing_event_TreeExpansionEvent;
};

// Vtype
struct _jc_javax_swing_event_TreeExpansionEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_TreeExpansionEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_TreeExpansionEvent$sub_refs {
	struct _jc_javax_swing_tree_TreePath$object	*path;
};

// Reference instance fields (object)
struct _jc_javax_swing_event_TreeExpansionEvent$refs {
    _jc_javax_swing_event_TreeExpansionEvent$sub_refs	javax_swing_event_TreeExpansionEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_TreeExpansionEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_TreeExpansionEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_swing_event_TreeExpansionEvent$sub_nonrefs	javax_swing_event_TreeExpansionEvent;
};

// Object instance structure
struct _jc_javax_swing_event_TreeExpansionEvent$object {
	_jc_javax_swing_event_TreeExpansionEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_TreeExpansionEvent$vtype	*vtype;
	_jc_javax_swing_event_TreeExpansionEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_TreeExpansionEvent$vtype _jc_javax_swing_event_TreeExpansionEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_TreeExpansionEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_TreeExpansionEvent$class_object;

#endif	/* _JC_javax_swing_event_TreeExpansionEvent_H_ */

==> jc-1.4.6.tar.gz: javax/swing/event/TreeExpansionEvent.h <==
// public class javax.swing.event.TreeExpansionEvent

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 60b136e49bd0d068 javax_swing_event_TreeExpansionEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_swing_event_TreeExpansionEvent_H_
#define _JC_javax_swing_event_TreeExpansionEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_swing_tree_TreePath$object;

// Typedefs
typedef struct _jc_javax_swing_event_TreeExpansionEvent$sub_refs	_jc_javax_swing_event_TreeExpansionEvent$sub_refs;
typedef struct _jc_javax_swing_event_TreeExpansionEvent$sub_nonrefs	_jc_javax_swing_event_TreeExpansionEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_TreeExpansionEvent$refs	_jc_javax_swing_event_TreeExpansionEvent$refs;
typedef struct _jc_javax_swing_event_TreeExpansionEvent$nonrefs	_jc_javax_swing_event_TreeExpansionEvent$nonrefs;
typedef struct _jc_javax_swing_event_TreeExpansionEvent$object	_jc_javax_swing_event_TreeExpansionEvent$object;

typedef const struct _jc_javax_swing_event_TreeExpansionEvent$vmethods	_jc_javax_swing_event_TreeExpansionEvent$vmethods;
typedef const struct _jc_javax_swing_event_TreeExpansionEvent$vtable	_jc_javax_swing_event_TreeExpansionEvent$vtable;
typedef const struct _jc_javax_swing_event_TreeExpansionEvent$vtype	_jc_javax_swing_event_TreeExpansionEvent$vtype;

// Constructors
extern void _jc_javax_swing_event_TreeExpansionEvent$method$_init$a701a601c3e52853(_jc_env *, struct _jc_javax_swing_event_TreeExpansionEvent$object *, struct _jc_java_lang_Object$object *, struct _jc_javax_swing_tree_TreePath$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_swing_tree_TreePath$object *_jc_javax_swing_event_TreeExpansionEvent$method$getPath$e6c9a7eed2216189(_jc_env *, struct _jc_javax_swing_event_TreeExpansionEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_event_TreeExpansionEvent$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_event_TreeExpansionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_TreeExpansionEvent$method_info$getPath$e6c9a7eed2216189;
extern _jc_method _jc_javax_swing_event_TreeExpansionEvent$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_event_TreeExpansionEvent$vmethods {
	struct _jc_javax_swing_tree_TreePath$object	*(*getPath$e6c9a7eed2216189)(_jc_env *, struct _jc_javax_swing_event_TreeExpansionEvent$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_event_TreeExpansionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_event_TreeExpansionEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_swing_event_TreeExpansionEvent$vmethods	javax_swing_event_TreeExpansionEvent;
};

// Vtype
struct _jc_javax_swing_event_TreeExpansionEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_TreeExpansionEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_TreeExpansionEvent$sub_refs {
	struct _jc_javax_swing_tree_TreePath$object	*path;
};

// Reference instance fields (object)
struct _jc_javax_swing_event_TreeExpansionEvent$refs {
    _jc_javax_swing_event_TreeExpansionEvent$sub_refs	javax_swing_event_TreeExpansionEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_TreeExpansionEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_TreeExpansionEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_swing_event_TreeExpansionEvent$sub_nonrefs	javax_swing_event_TreeExpansionEvent;
};

// Object instance structure
struct _jc_javax_swing_event_TreeExpansionEvent$object {
	_jc_javax_swing_event_TreeExpansionEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_TreeExpansionEvent$vtype	*vtype;
	_jc_javax_swing_event_TreeExpansionEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_TreeExpansionEvent$vtype _jc_javax_swing_event_TreeExpansionEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_TreeExpansionEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_TreeExpansionEvent$class_object;

#endif	/* _JC_javax_swing_event_TreeExpansionEvent_H_ */
